@@ -1,11 +1,11 @@
-import { CommonModule } from "@angular/common";
-import { HttpClientModule } from "@angular/common/http";
-import { NgModule } from "@angular/core";
-import { Routes } from "@angular/router";
-import { FormsModule } from "@angular/forms";
-import { NzIconModule } from "ng-zorro-antd/icon";
-import { RouterModule } from "@angular/router";
-import { GraphDbCfgComponent } from "./graphdb-cfg.component";
+import { CommonModule } from "@angular/common"
+import { HttpClientModule } from "@angular/common/http"
+import { NgModule } from "@angular/core"
+import { Routes } from "@angular/router"
+import { FormsModule } from "@angular/forms"
+import { NzIconModule } from "ng-zorro-antd/icon"
+import { RouterModule } from "@angular/router"
+import { GraphDbCfgComponent } from "./graphdb-cfg.component"
 
 // Define the child routes for this plugin.
 export const pluginRoutes: Routes = [
@@ -18,7 +18,7 @@ export const pluginRoutes: Routes = [
         pathMatch: "full",
         component: GraphDbCfgComponent,
     },
-];
+]
 
 // Define the root module for this plugin.
 // This module is loaded by the lazy loader, what ever this defines is what is started.
@@ -35,4 +35,5 @@ export const pluginRoutes: Routes = [
     providers: [],
     declarations: [GraphDbCfgComponent],
 })
-export class GraphDbCfgModule {}
+export class GraphDbCfgModule {
+}
